/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 03393
 |               DRUG SERVICES RESEARCH SURVEY (DSRS), 1990
 |           (DATASET 0002: PHASE II - ADMINISTRATOR INTERVIEW)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 03393-0002-statasetup.do)
 |
 **************************************************************************/

set mem 6m  /* Allocating 6 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Drug Services Research Survey (DSRS), 1990, Dataset 0002"

#delimit ;
label define Q1_COR    -9 "NOT ASCERTAINED" 1 "YES" 2 "NO" ;
label define Q2        -9 "NOT ASCERTAINED" 1 "DRUG ONLY" 2 "ALCOHOL ONLY"
                       3 "BOTH DRUG AND ALCOHOL" ;
label define Q3_SEP    -9 "NOT ASCERTAINED"
                       -5 "INAP - SRV UNIT DOES NOT TX BOTH DRUG AND ALCOHOL CLIENTS"
                       1 "YES" 2 "NO" ;
label define Q4_DIF    -9 "NOT ASCERTAINED"
                       -5 "INAP - SRV UNIT DOES NOT TX BOTH DRUG AND ALCOHOL CLIENTS"
                       1 "YES" 2 "NO" ;
label define Q5_DRUG   -9 "NOT ASCERTAINED"
                       -5 "INAP - BOTH DRUG & ALC CLIENTS NOT TX OR NOT SEPARATED"
                       1 "DRUG PROTOCOL DESCRIBED" ;
label define Q5_ALC    -9 "NOT ASCERTAINED"
                       -5 "INAP - BOTH DRUG & ALC CLIENTS NOT TX OR NOT SEPARATED"
                       1 "ALCOHOL PROTOCOL DESCRIBED" ;
label define Q6_COR    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q6A       -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - FIGURE FROM TELEPHONE INT IS CORRECT" ;
label define Q7_COR    -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q7A       -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - FIGURE FROM TELEPHONE INT IS CORRECT"
                       0 "NONE" ;
label define Q8        -9 "NOT ASCERTAINED" -8 "DON'T KNOW" ;
label define Q9        -9 "NOT ASCERTAINED - MISSING" -8 "DON'T KNOW"
                       1 "MORE" 2 "LESS" 3 "ABOUT THE SAME" ;
label define Q10A_HDD  -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q10B_HDD  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE HDD" 1 "YES"
                       2 "NO" ;
label define Q10C_HDD  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE HDD" ;
label define Q10A_HDF  -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q10B_HDF  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE HDF" 1 "YES"
                       2 "NO" ;
label define Q10C_HDF  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE HDF" ;
label define Q10A_RDD  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q10B_RDD  -9 "NOT ASCERTAINED"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE RDD" 1 "YES"
                       2 "NO" ;
label define Q10C_RDD  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE RDD" ;
label define Q10A_RDF  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q10B_RDF  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE RDF" 1 "YES"
                       2 "NO" ;
label define Q10C_RDF  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE RDF" ;
label define Q10A_ODD  -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q10B_ODD  -9 "NOT ASCERTAINED"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE ODD" 1 "YES"
                       2 "NO" ;
label define Q10C_ODD  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE ODD" ;
label define Q10A_ODM  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q10B_ODM  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE ODM" 1 "YES"
                       2 "NO" ;
label define Q10C_ODM  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE ODM" ;
label define Q10A_ODF  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q10B_ODF  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE ODF" 1 "YES"
                       2 "NO" ;
label define Q10C_ODF  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE ODF" ;
label define Q11_HDD   -9 "NOT ASCERTAINED"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE HDD"
                       0 "BOX NOT CHECKED, PRESUMED NO"
                       1 "WAITING LIST POLICY DESCRIBED" ;
label define Q11_HDF   -9 "NOT ASCERTAINED"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE HDF"
                       0 "BOX NOT CHECKED, PRESUMED NO"
                       1 "WAITING LIST POLICY DESCRIBED" ;
label define Q11_RDD   -9 "NOT ASCERTAINED"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE RDD"
                       0 "BOX NOT CHECKED, PRESUMED NO"
                       1 "WAITING LIST POLICY DESCRIBED" ;
label define Q11_RDF   -9 "NOT ASCERTAINED"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE RDF"
                       0 "BOX NOT CHECKED, PRESUMED NO"
                       1 "WAITING LIST POLICY DESCRIBED" ;
label define Q11_ODD   -9 "NOT ASCERTAINED"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE ODD"
                       0 "BOX NOT CHECKED, PRESUMED NO"
                       1 "WAITING LIST POLICY DESCRIBED" ;
label define Q11_ODM   -9 "NOT ASCERTAINED"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE ODM"
                       0 "BOX NOT CHECKED, PRESUMED NO"
                       1 "WAITING LIST POLICY DESCRIBED" ;
label define Q11_ODF   -9 "NOT ASCERTAINED"
                       -5 "INAP - SRV UNIT DID NOT PROVIDE ODF"
                       0 "BOX NOT CHECKED, PRESUMED NO"
                       1 "WAITING LIST POLICY DESCRIBED" ;
label define Q12A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q12B      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q12C      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q12D      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES (SPECIFY)"
                       2 "NO" ;
label define Q13A      1 "YES" 2 "NO" ;
label define Q13A_TNS  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DOES NOT TX TEENS" 1 "YES" 2 "NO" ;
label define Q13B      -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q13B_PRG  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DOES NOT TX PREGNANT WOMEN"
                       1 "YES" 2 "NO" ;
label define Q13C      -9 "NOT ASCERTAINED" 1 "YES" 2 "NO" ;
label define Q13C_IVD  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DOES NOT TX IV DRUG USERS" 1 "YES"
                       2 "NO" ;
label define Q13D      -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q13D_DDC  -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DOES NOT TX DUAL DX PXS" 1 "YES"
                       2 "NO" ;
label define Q13E      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q14A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q14B      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q14C      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q15_CERT  -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q15A      -9 "NOT ASCERRTAINED"
                       -5 "INAP - SRV UNIT DOES NOT HAVE COUNSELORS W/ SPECIAL CERTS"
                       1 "DESCRIPTION OF SPECIAL CERTIFICATION GIVEN" ;
label define Q16_COMP  1 "YES" 2 "NO" ;
label define Q17A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DOES NOT HAVE COMPUTER RECORDS"
                       1 "YES" 2 "NO" ;
label define Q17B      -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DOES NOT HAVE COMPUTER RECORDS"
                       1 "YES" 2 "NO" ;
label define Q17C      -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DOES NOT HAVE COMPUTER RECORDS"
                       1 "YES" 2 "NO" ;
label define Q17D      -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAP - SRV UNIT DOES NOT HAVE COMPUTER RECORDS"
                       1 "YES" 2 "NO" ;
label define Q18_OWN   -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       1 "PUBLICLY OWNED" 2 "PRIVATELY OWNED, NON-PROFIT"
                       3 "PRIVATELY OWNED, FOR PROFIT" ;
label define Q19A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q19B      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q19C      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q19D      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q19E      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q19F      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES (SPECIFY)"
                       2 "NO" ;
label define Q20A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q20B      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q20C      -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES (SPECIFY)"
                       2 "NO" ;
label define Q21_OTHU  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q22_MULT  -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define Q23A_1    -9 "NOT ASCERTAINED" -7 "REFUSED" 1 "GIVEN"
                       2 "DO NOT HAVE" ;
label define Q23A_2    -9 "NOT ASCERTAINED" -7 "REFUSED" 1 "GIVEN"
                       2 "DO NOT HAVE" ;
label define Q23A_3    -9 "NOT ASCERTAINED" -7 "REFUSED" 1 "GIVEN"
                       2 "DO NOT HAVE" ;
label define Q23A_4    -9 "NOT ASCERTAINED" -7 "REFUSED" 1 "GIVEN"
                       2 "DO NOT HAVE" ;
label define Q23A_5    -9 "NOT ASCERTAINED" -7 "REFUSED" 1 "GIVEN"
                       2 "DO NOT HAVE" ;
label define Q23B_1    -9 "NOT ASCERTAINED" -7 "REFUSED" 1 "GIVEN"
                       2 "DO NOT HAVE" ;
label define Q23B_2    -9 "NOT ASCERTAINED" -7 "REFUSED" 1 "GIVEN"
                       2 "DO NOT HAVE" ;
label define Q23B_3    -9 "NOT ASCERTAINED" -7 "REFUSED" 1 "GIVEN"
                       2 "DO NOT HAVE" ;
label define Q23B_4    -9 "NOT ASCERTAINED" -7 "REFUSED" 1 "GIVEN"
                       2 "DO NOT HAVE" ;
label define Q23B_5    -9 "NOT ASCERTAINED" -7 "REFUSED" 1 "GIVEN"
                       2 "DO NOT HAVE" ;
label define Q23C_1    -9 "NOT ASCERTAINED" -7 "REFUSED" 1 "GIVEN"
                       2 "DO NOT HAVE" ;
label define Q23C_2    -9 "NOT ASCERTAINED" -7 "REFUSED" 1 "GIVEN"
                       2 "DO NOT HAVE" ;
label define Q23C_3    -9 "NOT ASCERTAINED" -7 "REFUSED" 1 "GIVEN"
                       2 "DO NOT HAVE" ;
label define CORRFAC   0 "NO" 1 "YES" ;
label define ALCHONLY  0 "NO" 1 "YES" ;
label define STRATUM   1 "HOSPITAL IN-PATIENT DRUG TREATMENT"
                       2 "RESIDENTIAL DRUG TREATMENT"
                       3 "OUT-PATIENT DRUG DETOXIFICATION MAINTENANCE"
                       4 "OUT-PATIENT DRUG-FREE TREATMENT"
                       5 "ALCOHOL TREATMENT ONLY" 6 "UNKNOWN TREATMENT TYPE" ;
label define REGION    1 "NORTHEAST" 2 "NORTH CENTRAL" 3 "SOUTH" 4 "WEST" ;
label define QA1       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define QA1A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAPPLICABLE - BLANK, CODED 1, 8 OR 9 IN QA1"
                       1 "YES" 2 "NO" ;
label define QA2       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define QA3       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define QA3A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAPPLICABLE - BLANK, CODED 1, 8 OR 9 IN QA3"
                       1 "YES" 2 "NO" ;
label define QA4       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define QA4A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAPPLICABLE - BLANK, CODED 1, 8 OR 9 IN QA4"
                       1 "YES" 2 "NO" ;
label define QA5       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define QA5A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAPPLICABLE - BLANK, CODED 2, 8 OR 9 IN QA5"
                       1 "YES" 2 "NO" ;
label define QA6       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define QA6A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAPPLICABLE - BLANK, CODED 2, 8 OR 9 IN QA6A"
                       1 "YES" 2 "NO" ;
label define QB1       -9 "NOT ASCERTAINED" -8 "DON'T KNOW" 1 "YES" 2 "NO" ;
label define QB1A      -9 "NOT ASCERTAINED" -8 "DON'T KNOW"
                       -5 "INAPPLICABLE - BLANK, CODED 1, 8 OR 9 IN QB1"
                       1 "YES" 2 "NO" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace OBS_NUM = . if (OBS_NUM <= -1 )
replace Q1_COR = . if (Q1_COR <= -1 )
replace Q2 = . if (Q2 <= -1 )
replace Q3_SEP = . if (Q3_SEP <= -1 )
replace Q4_DIF = . if (Q4_DIF <= -1 )
replace Q5_DRUG = . if (Q5_DRUG <= -1 )
replace Q5_ALC = . if (Q5_ALC <= -1 )
replace Q6_COR = . if (Q6_COR <= -1 )
replace Q6A = . if (Q6A <= -1 )
replace Q7_COR = . if (Q7_COR <= -1 )
replace Q7A = . if (Q7A <= -1 )
replace Q8 = . if (Q8 <= -1 )
replace Q9 = . if (Q9 <= -1 )
replace Q10A_HDD = . if (Q10A_HDD <= -1 )
replace Q10B_HDD = . if (Q10B_HDD <= -1 )
replace Q10C_HDD = . if (Q10C_HDD <= -1 )
replace Q10A_HDF = . if (Q10A_HDF <= -1 )
replace Q10B_HDF = . if (Q10B_HDF <= -1 )
replace Q10C_HDF = . if (Q10C_HDF <= -1 )
replace Q10A_RDD = . if (Q10A_RDD <= -1 )
replace Q10B_RDD = . if (Q10B_RDD <= -1 )
replace Q10C_RDD = . if (Q10C_RDD <= -1 )
replace Q10A_RDF = . if (Q10A_RDF <= -1 )
replace Q10B_RDF = . if (Q10B_RDF <= -1 )
replace Q10C_RDF = . if (Q10C_RDF <= -1 )
replace Q10A_ODD = . if (Q10A_ODD <= -1 )
replace Q10B_ODD = . if (Q10B_ODD <= -1 )
replace Q10C_ODD = . if (Q10C_ODD <= -1 )
replace Q10A_ODM = . if (Q10A_ODM <= -1 )
replace Q10B_ODM = . if (Q10B_ODM <= -1 )
replace Q10C_ODM = . if (Q10C_ODM <= -1 )
replace Q10A_ODF = . if (Q10A_ODF <= -1 )
replace Q10B_ODF = . if (Q10B_ODF <= -1 )
replace Q10C_ODF = . if (Q10C_ODF <= -1 )
replace Q11_HDD = . if (Q11_HDD <= -1 )
replace Q11_HDF = . if (Q11_HDF <= -1 )
replace Q11_RDD = . if (Q11_RDD <= -1 )
replace Q11_RDF = . if (Q11_RDF <= -1 )
replace Q11_ODD = . if (Q11_ODD <= -1 )
replace Q11_ODM = . if (Q11_ODM <= -1 )
replace Q11_ODF = . if (Q11_ODF <= -1 )
replace Q12A = . if (Q12A <= -1 )
replace Q12B = . if (Q12B <= -1 )
replace Q12C = . if (Q12C <= -1 )
replace Q12D = . if (Q12D <= -1 )
replace Q13A = . if (Q13A <= -1 )
replace Q13A_TNS = . if (Q13A_TNS <= -1 )
replace Q13B = . if (Q13B <= -1 )
replace Q13B_PRG = . if (Q13B_PRG <= -1 )
replace Q13C = . if (Q13C <= -1 )
replace Q13C_IVD = . if (Q13C_IVD <= -1 )
replace Q13D = . if (Q13D <= -1 )
replace Q13D_DDC = . if (Q13D_DDC <= -1 )
replace Q13E = . if (Q13E <= -1 )
replace Q14A = . if (Q14A <= -1 )
replace Q14B = . if (Q14B <= -1 )
replace Q14C = . if (Q14C <= -1 )
replace Q15_CERT = . if (Q15_CERT <= -1 )
replace Q15A = . if (Q15A <= -1 )
replace Q16_COMP = . if (Q16_COMP <= -1 )
replace Q17A = . if (Q17A <= -1 )
replace Q17B = . if (Q17B <= -1 )
replace Q17C = . if (Q17C <= -1 )
replace Q17D = . if (Q17D <= -1 )
replace Q18_OWN = . if (Q18_OWN <= -1 )
replace Q19A = . if (Q19A <= -1 )
replace Q19B = . if (Q19B <= -1 )
replace Q19C = . if (Q19C <= -1 )
replace Q19D = . if (Q19D <= -1 )
replace Q19E = . if (Q19E <= -1 )
replace Q19F = . if (Q19F <= -1 )
replace Q20A = . if (Q20A <= -1 )
replace Q20B = . if (Q20B <= -1 )
replace Q20C = . if (Q20C <= -1 )
replace Q21_OTHU = . if (Q21_OTHU <= -1 )
replace Q22_MULT = . if (Q22_MULT <= -1 )
replace Q23A_1 = . if (Q23A_1 <= -1 )
replace Q23A_2 = . if (Q23A_2 <= -1 )
replace Q23A_3 = . if (Q23A_3 <= -1 )
replace Q23A_4 = . if (Q23A_4 <= -1 )
replace Q23A_5 = . if (Q23A_5 <= -1 )
replace Q23B_1 = . if (Q23B_1 <= -1 )
replace Q23B_2 = . if (Q23B_2 <= -1 )
replace Q23B_3 = . if (Q23B_3 <= -1 )
replace Q23B_4 = . if (Q23B_4 <= -1 )
replace Q23B_5 = . if (Q23B_5 <= -1 )
replace Q23C_1 = . if (Q23C_1 <= -1 )
replace Q23C_2 = . if (Q23C_2 <= -1 )
replace Q23C_3 = . if (Q23C_3 <= -1 )
replace CORRFAC = . if (CORRFAC <= -1 )
replace ALCHONLY = . if (ALCHONLY <= -1 )
replace STRATUM = . if (STRATUM <= -1 )
replace REGION = . if (REGION <= -1 )
replace QA1 = . if (QA1 <= -1 )
replace QA1A = . if (QA1A <= -1 )
replace QA2 = . if (QA2 <= -1 )
replace QA3 = . if (QA3 <= -1 )
replace QA3A = . if (QA3A <= -1 )
replace QA4 = . if (QA4 <= -1 )
replace QA4A = . if (QA4A <= -1 )
replace QA5 = . if (QA5 <= -1 )
replace QA5A = . if (QA5A <= -1 )
replace QA6 = . if (QA6 <= -1 )
replace QA6A = . if (QA6A <= -1 )
replace QB1 = . if (QB1 <= -1 )
replace QB1A = . if (QB1A <= -1 )
replace REP_STRA = . if (REP_STRA <= -1 )
replace VWGHT = . if (VWGHT <= -1.00000 )
replace VWT1 = . if (VWT1 <= -1.00000 )
replace VWT2 = . if (VWT2 <= -1.00000 )
replace VWT3 = . if (VWT3 <= -1.00000 )
replace VWT4 = . if (VWT4 <= -1.00000 )
replace VWT5 = . if (VWT5 <= -1.00000 )
replace VWT6 = . if (VWT6 <= -1.00000 )
replace VWT7 = . if (VWT7 <= -1.00000 )
replace VWT8 = . if (VWT8 <= -1.00000 )
replace VWT9 = . if (VWT9 <= -1.00000 )
replace VWT10 = . if (VWT10 <= -1.00000 )
replace VWT11 = . if (VWT11 <= -1.00000 )
replace VWT12 = . if (VWT12 <= -1.00000 )
replace VWT13 = . if (VWT13 <= -1.00000 )
replace VWT14 = . if (VWT14 <= -1.00000 )
replace VWT15 = . if (VWT15 <= -1.00000 )
replace VWT16 = . if (VWT16 <= -1.00000 )
replace VWT17 = . if (VWT17 <= -1.00000 )
replace VWT18 = . if (VWT18 <= -1.00000 )
replace VWT19 = . if (VWT19 <= -1.00000 )
replace VWT20 = . if (VWT20 <= -1.00000 )
replace VWT21 = . if (VWT21 <= -1.00000 )
replace VWT22 = . if (VWT22 <= -1.00000 )
replace VWT23 = . if (VWT23 <= -1.00000 )
replace VWT24 = . if (VWT24 <= -1.00000 )
replace VWT25 = . if (VWT25 <= -1.00000 )
replace VWT26 = . if (VWT26 <= -1.00000 )
replace VWT27 = . if (VWT27 <= -1.00000 )
replace VWT28 = . if (VWT28 <= -1.00000 )
replace VWT29 = . if (VWT29 <= -1.00000 )
replace VWT30 = . if (VWT30 <= -1.00000 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

